import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';
import screenfull from 'screenfull';

/**
 * The underlying scrollContainerRef should be an actual node, not a Fragment. Otherwise, it will just be null
 * You HAVE to make sure overflow-x is not set on the scrollContainerRef or body. This will make scrollTop default to 0 on Chrome Mobile
 */

var Screenfull = function (_React$PureComponent) {
  babelHelpers.inherits(Screenfull, _React$PureComponent);

  function Screenfull(props) {
    babelHelpers.classCallCheck(this, Screenfull);

    var _this = babelHelpers.possibleConstructorReturn(this, (Screenfull.__proto__ || Object.getPrototypeOf(Screenfull)).call(this, props));

    _this.getNode = function () {
      var scrollContainerRef = _this.props.scrollContainerRef;

      return scrollContainerRef ? ReactDOM.findDOMNode(scrollContainerRef) // eslint-disable-line react/no-find-dom-node
      : typeof document !== 'undefined' && document.body;
    };

    _this.getFullScreenNode = function () {
      return document.documentElement || document.body;
    };

    _this.handleScroll = function (event) {
      var scrollPos = event.currentTarget.scrollTop;
      var going = 'down';
      if (_this.scroll !== 0 && scrollPos < _this.scroll) going = 'up';

      _this.scroll = scrollPos;

      if (going === 'up' && screenfull.isFullscreen) {
        screenfull.exit();
      } else if (going === 'down' && !screenfull.isFullscreen) {
        screenfull.request(_this.getFullScreenNode());
      }
    };

    _this.scroll = 0;
    return _this;
  }

  babelHelpers.createClass(Screenfull, [{
    key: 'componentDidMount',
    value: function componentDidMount() {
      var _props = this.props,
          forceFullScreen = _props.forceFullScreen,
          mobileOnly = _props.mobileOnly;

      if (mobileOnly && !this.isMobile()) return;
      if (forceFullScreen) {
        if (screenfull.enabled) screenfull.request(this.getFullScreenNode());
        return;
      }

      var node = this.getNode();
      if (node && screenfull.enabled) {
        node.addEventListener('scroll', this.handleScroll, { passive: true }, true);
      }
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      var _props2 = this.props,
          forceFullScreen = _props2.forceFullScreen,
          mobileOnly = _props2.mobileOnly;

      if (mobileOnly && !this.isMobile()) return;
      if (screenfull.enabled) screenfull.exit();
      if (forceFullScreen) {
        return;
      }
      var node = this.getNode();
      if (node && screenfull.enabled) {
        node.removeEventListener('scroll', this.handleScroll);
      }
    }
  }, {
    key: 'isMobile',
    value: function isMobile() {
      var maxPixelsForMobile = this.props.maxPixelsForMobile;

      if (typeof window === 'undefined') return false;
      var width = window.innerWidth;
      return width <= maxPixelsForMobile;
    }
  }, {
    key: 'render',
    value: function render() {
      return null;
    }
  }]);
  return Screenfull;
}(React.PureComponent);

Screenfull.propTypes = {
  scrollContainerRef: PropTypes.element,
  forceFullScreen: PropTypes.bool,
  mobileOnly: PropTypes.bool,
  maxPixelsForMobile: PropTypes.number
};
Screenfull.defaultProps = {
  scrollContainerRef: null,
  forceFullScreen: false,
  mobileOnly: true,
  maxPixelsForMobile: 768
};
export default Screenfull;